@@ -14,10 +14,10 @@ Uploaders:
  Aloïs Micard <alois@micard.lu>,
 Section: news
 Testsuite: autopkgtest-pkg-go
-Priority: optional
 Build-Depends:
  debhelper-compat (= 13),
  dh-sequence-golang,
+ dpkg-build-api (= 1),
  golang-any,
  golang-github-advancedlogic-goose-dev,
  golang-github-fatih-color-dev,
@@ -28,7 +28,6 @@ Standards-Version: 4.7.0
 Vcs-Browser: https://salsa.debian.org/go-team/packages/terminews
 Vcs-Git: https://salsa.debian.org/go-team/packages/terminews.git
 Homepage: https://github.com/antavelos/terminews
-Rules-Requires-Root: no
 XS-Go-Import-Path: github.com/antavelos/terminews
 
 Package: terminews
@@ -111,10 +110,10 @@ require (
 		t.Fatalf("Could not create dummy Debian package: %v", err)
 	}
 
-	deps, err := parseGoModDependencies(filepath.Join(tmpDir, "dummy-package"), map[string]string{
-		"github.com/charmbracelet/glamour": "golang-github-charmbracelet-glamour-dev",
-		"github.com/google/go-github":      "golang-github-google-go-github-dev",
-		"github.com/gregjones/httpcache":   "golang-github-gregjones-httpcache-dev",
+	deps, err := parseGoModDependencies(filepath.Join(tmpDir, "dummy-package"), map[string]debianPackage{
+		"github.com/charmbracelet/glamour": {binary: "golang-github-charmbracelet-glamour-dev", source: "golang-github-charmbracelet-glamour"},
+		"github.com/google/go-github":      {binary: "golang-github-google-go-github-dev", source: "golang-github-google-go-github"},
+		"github.com/gregjones/httpcache":   {binary: "golang-github-gregjones-httpcache-dev", source: "golang-github-gregjones-httpcache"},
 	})
 	if err != nil {
 		t.Fatalf("Could not parse go.mod dependencies: %v", err)
