@@ -5,6 +5,7 @@ import (
 	"log"
 	"os"
 	"path/filepath"
+	"regexp"
 	"sort"
 	"strings"
 	"time"
@@ -86,6 +87,7 @@ func writeDebianGitIgnore(dir, debLib, debProg string, pkgType packageType) erro
 	fmt.Fprintf(f, "*.log\n")
 	fmt.Fprintf(f, "*.substvars\n")
 	fmt.Fprintf(f, "/.debhelper/\n")
+	fmt.Fprintf(f, "/_build/\n")
 	fmt.Fprintf(f, "/debhelper-build-stamp\n")
 	fmt.Fprintf(f, "/files\n")
 
@@ -192,14 +194,13 @@ func writeDebianControl(dir, gopkg, debsrc, debLib, debProg string, pkgType pack
 
 	fmt.Fprintf(f, "Source: %s\n", debsrc)
 	fmt.Fprintf(f, "Section: golang\n")
-	fmt.Fprintf(f, "Priority: optional\n")
 	fmt.Fprintf(f, "Maintainer: Debian Go Packaging Team <team+pkg-go@tracker.debian.org>\n")
 	fprintfControlField(f, "Uploaders", []string{getDebianName() + " <" + getDebianEmail() + ">"})
-	fmt.Fprintf(f, "Rules-Requires-Root: no\n")
 
 	builddeps := append([]string{
 		"debhelper-compat (= 13)",
 		"dh-sequence-golang",
+		"dpkg-build-api (= 1)",
 		"golang-any"},
 		dependencies...)
 	sort.Strings(builddeps)
@@ -259,9 +260,19 @@ func writeDebianCopyright(dir, gopkg string, vendorDirs []string, hasGodeps bool
 		linebreak = "\n"
 	}
 
+	// Determine a reasonable default for the upstream project's name.  If the
+	// module is named something like example.com/foo/bar, then use the final
+	// component "bar" as the project name.  But if the module name has a major
+	// version suffix, such as example.com/foo/bar/v2, then strip off the suffix
+	// before taking the final component.
+	upstreamName := filepath.Base(gopkg)
+	if regexp.MustCompile(`^v\d+$`).MatchString(upstreamName) {
+		upstreamName = filepath.Base(filepath.Dir(gopkg))
+	}
+
 	fmt.Fprintf(f, "Format: https://www.debian.org/doc/packaging-manuals/copyright-format/1.0/\n")
 	fmt.Fprintf(f, "Source: %s\n", getHomepageForGopkg(gopkg))
-	fmt.Fprintf(f, "Upstream-Name: %s\n", filepath.Base(gopkg))
+	fmt.Fprintf(f, "Upstream-Name: %s\n", upstreamName)
 	fmt.Fprintf(f, "Upstream-Contact: TODO\n")
 	if len(vendorDirs) > 0 || hasGodeps {
 		fmt.Fprintf(f, "Files-Excluded:\n")
@@ -299,7 +310,11 @@ func writeDebianRules(dir string, pkgType packageType) error {
 	fmt.Fprintf(f, "#!/usr/bin/make -f\n")
 	fmt.Fprintf(f, "\n")
 	fmt.Fprintf(f, "%%:\n")
-	fmt.Fprintf(f, "\tdh $@ --builddirectory=_build --buildsystem=golang\n")
+	fmt.Fprintf(f, "\tdh $@ --builddirectory=debian/_build --buildsystem=golang\n")
+	// Note: The above `--builddirectory=debian/_build` will eventually be obsolete
+	// in 2028+ then the dh-golang version 1.64+ that has merged
+	// https://salsa.debian.org/go-team/packages/dh-golang/-/merge_requests/26
+
 	if pkgType == typeProgram {
 		fmt.Fprintf(f, "\n")
 		fmt.Fprintf(f, "override_dh_auto_install:\n")
